@@ -1,7 +1,7 @@
 package Perinci::Object;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.24'; # VERSION
+our $DATE = '2016-12-28'; # DATE
+our $VERSION = '0.29'; # VERSION
 
 use 5.010001;
 use strict;
@@ -9,7 +9,8 @@ use warnings;
 
 require Exporter;
 our @ISA    = qw(Exporter);
-our @EXPORT = qw(rimeta risub rivar ripkg envres envresmulti riresmeta);
+our @EXPORT = qw(rimeta risub rivar ripkg envres envresmulti envrestable
+                 riresmeta);
 
 sub rimeta {
     require Perinci::Object::Metadata;
@@ -41,6 +42,11 @@ sub envresmulti {
     Perinci::Object::EnvResultMulti->new(@_);
 }
 
+sub envrestable {
+    require Perinci::Object::EnvResultTable;
+    Perinci::Object::EnvResultTable->new(@_);
+}
+
 sub riresmeta {
     require Perinci::Object::ResMeta;
     Perinci::Object::ResMeta->new(@_);
@@ -61,12 +67,12 @@ Perinci::Object - Object-oriented interface for Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.24 of Perinci::Object (from Perl distribution Perinci-Object), released on 2015-09-03.
+This document describes version 0.29 of Perinci::Object (from Perl distribution Perinci-Object), released on 2016-12-28.
 
 =head1 SYNOPSIS
 
  use Perinci::Object; # automatically exports risub(), rivar(), ripkg(),
-                      # envres(), envresmulti(), riresmeta()
+                      # envres(), envresmulti(), envrestable(), riresmeta()
  use Data::Dump; # for dd()
 
  # OO interface to function metadata.
@@ -117,7 +123,7 @@ This document describes version 0.24 of Perinci::Object (from Perl distribution
  # OO interface to function/method result metadata
  my $riresmeta = riresmeta { ... };
 
- # an example of using riresmulti()
+ # an example of using envresmulti()
  sub myfunc {
      ...
 
@@ -133,6 +139,16 @@ This document describes version 0.24 of Perinci::Object (from Perl distribution
      return $envres->as_struct;
  }
 
+ # an example of using envrestable()
+ sub myfunc {
+     ...
+     my $envres = envrestable();
+     $envres->add_field('foo');
+     $envres->add_field('bar');
+     ...
+     return $envres->as_struct;
+ }
+
 =head1 DESCRIPTION
 
 L<Rinci> works using pure data structures, but sometimes it's convenient to have
@@ -165,14 +181,14 @@ Exported by default. A shortcut for Perinci::Object::EnvResult->new($res).
 
 Exported by default. A shortcut for Perinci::Object::EnvResultMulti->new($res).
 
+=head2 envrestable $res => OBJECT
+
+Exported by default. A shortcut for Perinci::Object::EnvResultTable->new($res).
+
 =head2 riresmeta $resmeta => OBJECT
 
 Exported by default. A shortcut for Perinci::Object::ResMeta->new($res).
 
-=head1 SEE ALSO
-
-L<Rinci>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Perinci-Object>.
@@ -189,13 +205,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Rinci>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
